import java.util.*;

import java.sql.*;
import org.hibernate.*;
import org.hibernate.criterion.*;

public class Main {
	
	public static void main(String[] args) {
		HibernateUtil.setup("create table Supplier ( id int, name VARCHAR);");
		HibernateUtil.setup("create table Product ( id int, name VARCHAR, description VARCHAR, price double,supplierId int);");
		
		prepareData();
		Session session = HibernateUtil.currentSession();
		
        Criteria crit = session.createCriteria(Product.class);
        Criterion price = Restrictions.gt("price",new Double(25.0));
        Criterion name = Restrictions.like("name","P%");
        LogicalExpression orExp = Restrictions.or(price,name);
        crit.add(orExp);
        crit.add(Restrictions.ilike("description","for%"));
        List results = crit.list();
        displayProductsList(results);
		
		
        HibernateUtil.checkData("select * from Supplier");
        HibernateUtil.checkData("select * from Product");

	}
    public static void displayProductsList(List list){
        Iterator iter = list.iterator();
        if (!iter.hasNext()){
            System.out.println("No products to display.");
            return;
        }
        while (iter.hasNext()){
            Product product = (Product) iter.next();
            String msg = product.getSupplier().getName() + "\t";
            msg += product.getName() + "\t";
            msg += product.getPrice() + "\t";
            msg += product.getDescription();
            System.out.println(msg);
        }
    }

	private static void prepareData(){
        Session session = HibernateUtil.currentSession();

        Supplier supplier1 = new Supplier();
        supplier1.setName("Supplier Name 1");
        session.save(supplier1);
        
        Supplier supplier2 = new Supplier();
        supplier2.setName("Supplier Name 2");
        session.save(supplier2);        
        
        Product product1 = new Product("Product 1","Name for Product 1", 2.0);
        product1.setSupplier(supplier1);
        supplier1.getProducts().add(product1);
        session.save(product1);
        
        Product product12 = new Product("Product 2","Name for Product 2", 22.0);
        product12.setSupplier(supplier1);
        supplier1.getProducts().add(product12);        
        session.save(product12);
        
        Product product2 = new Product("Product 3", "Name for Product 3", 30.0);
        product2.setSupplier(supplier2);
        supplier2.getProducts().add(product2);
        session.save(product2);
        
        session.flush();
        HibernateUtil.closeSession();
	}
}